@@ -156,6 +156,18 @@ def has_pyftpdlib ():
 need_pyftpdlib = _need_func(has_pyftpdlib, "pyftpdlib")
 
 
+@memoized
+def has_biplib ():
+    """Test if biplib is available."""
+    try:
+        import biplib
+        return True
+    except ImportError:
+        return False
+
+need_biplib = _need_func(has_biplib, "biplib")
+
+
 @memoized
 def has_newsserver (server):
     import nntplib
@@ -233,5 +245,14 @@ def limit_time (seconds, skip=False):
     return run_limited
 
 
+def get_file (filename=None):
+    """
+    Get file name located within 'data' directory.
+    """
+    directory = os.path.join("tests", "checker", "data")
+    if filename:
+        return unicode(os.path.join(directory, filename))
+    return unicode(directory)
+
 if __name__ == '__main__':
     print has_clamav(), has_network(), has_msgfmt(), has_posix(), has_proxy()
